@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006,2007,2011 Guido Guenther <agx@sigxcpu.org>
+# (C) 2006,2007,2011,2016 Guido Guenther <agx@sigxcpu.org>
 # (C) 2012 Intel Corporation <markus.lehtonen@linux.intel.com>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 #    <http://www.gnu.org/licenses/>
 """Import an RPM source package into a Git repository"""
 
-from six.moves import configparser
 import sys
 import re
 import os
@@ -31,12 +30,13 @@ from six.moves import urllib
 import gbp.command_wrappers as gbpc
 from gbp.tmpfile import init_tmpdir, del_tmpdir, tempfile
 from gbp.rpm import (parse_srpm, guess_spec, SpecFile, NoSpecError,
-                     RpmUpstreamSource, compose_version_str)
+                     RpmUpstreamSource, compose_version_str, filter_version)
 from gbp.rpm.git import (RpmGitRepository, GitRepositoryError)
 from gbp.git.modifier import GitModifier
 from gbp.config import (GbpOptionParserRpm, GbpOptionGroup,
-                       no_upstream_branch_msg)
+                        no_upstream_branch_msg)
 from gbp.errors import GbpError
+from gbp.scripts.common import ExitCodes
 import gbp.log
 from gbp.pkg import parse_archive_filename
 
@@ -45,6 +45,7 @@ Repository does not have branch '%s' for packaging/distribution sources.
 You need to reate it or use --packaging-branch to specify it.
 """
 
+
 class SkipImport(Exception):
     """Nothing imported"""
     pass
@@ -64,6 +65,7 @@ def download_file(target_dir, url):
         raise GbpError("Download failed: %s" % err.reason)
     return local_fn
 
+
 def download_source(pkg):
     """Download package from a remote location"""
     if re.match(r'[a-z]{1,5}://', pkg):
@@ -122,70 +124,71 @@ def build_parser(name):
         parser = GbpOptionParserRpm(command=os.path.basename(name),
                                     prefix='',
                                     usage='%prog [options] /path/to/package'
-                                          '.src.rpm')
-    except configparser.ParsingError as err:
+                                          '.src.rpm [target]')
+    except GbpError as err:
         gbp.log.err(err)
         return None
 
     import_group = GbpOptionGroup(parser, "import options",
-                      "pristine-tar and filtering")
+                                  "pristine-tar and filtering")
     tag_group = GbpOptionGroup(parser, "tag options",
-                      "options related to git tag creation")
+                               "options related to git tag creation")
     branch_group = GbpOptionGroup(parser, "version and branch naming options",
-                      "version number and branch layout options")
+                                  "version number and branch layout options")
 
-    for group in [import_group, branch_group, tag_group ]:
+    for group in [import_group, branch_group, tag_group]:
         parser.add_option_group(group)
 
     parser.add_option("-v", "--verbose", action="store_true", dest="verbose",
                       default=False, help="verbose command execution")
     parser.add_config_file_option(option_name="color", dest="color",
-                      type='tristate')
+                                  type='tristate')
     parser.add_config_file_option(option_name="color-scheme",
                                   dest="color_scheme")
     parser.add_config_file_option(option_name="tmp-dir", dest="tmp_dir")
     parser.add_config_file_option(option_name="vendor", action="store",
-                    dest="vendor")
+                                  dest="vendor")
     parser.add_option("--download", action="store_true", dest="download",
                       default=False, help="download source package")
     branch_group.add_config_file_option(option_name="packaging-branch",
-                      dest="packaging_branch")
+                                        dest="packaging_branch")
     branch_group.add_config_file_option(option_name="upstream-branch",
-                      dest="upstream_branch")
+                                        dest="upstream_branch")
     branch_group.add_boolean_config_file_option(
-                      option_name="create-missing-branches",
-                      dest="create_missing_branches")
+        option_name="create-missing-branches",
+        dest="create_missing_branches")
     branch_group.add_option("--orphan-packaging", action="store_true",
-                      dest="orphan_packaging", default=False,
-                      help="The packaging branch doesn't base on upstream")
+                            dest="orphan_packaging", default=False,
+                            help="The packaging branch doesn't base on upstream")
     branch_group.add_option("--native", action="store_true",
-                      dest="native", default=False,
-                      help="This is a dist native package, no separate "
-                           "upstream branch")
+                            dest="native", default=False,
+                            help="This is a dist native package, no separate "
+                            "upstream branch")
 
     tag_group.add_boolean_config_file_option(option_name="sign-tags",
-                      dest="sign_tags")
+                                             dest="sign_tags")
     tag_group.add_config_file_option(option_name="keyid",
-                      dest="keyid")
+                                     dest="keyid")
     tag_group.add_config_file_option(option_name="packaging-tag",
-                      dest="packaging_tag")
+                                     dest="packaging_tag")
     tag_group.add_config_file_option(option_name="upstream-tag",
-                      dest="upstream_tag")
+                                     dest="upstream_tag")
 
     import_group.add_config_file_option(option_name="filter",
-                      dest="filters", action="append")
+                                        dest="filters", action="append")
     import_group.add_boolean_config_file_option(option_name="pristine-tar",
-                      dest="pristine_tar")
+                                                dest="pristine_tar")
     import_group.add_option("--allow-same-version", action="store_true",
-                      dest="allow_same_version", default=False,
-                      help="allow to import already imported version")
+                            dest="allow_same_version", default=False,
+                            help="allow to import already imported version")
     import_group.add_boolean_config_file_option(
-                      option_name="author-is-committer",
-                      dest="author_is_committer")
+        option_name="author-is-committer",
+        dest="author_is_committer")
     import_group.add_config_file_option(option_name="packaging-dir",
-                      dest="packaging_dir")
+                                        dest="packaging_dir")
     return parser
 
+
 def parse_args(argv):
     """Parse commandline arguments"""
     parser = build_parser(argv[0])
@@ -205,8 +208,16 @@ def main(argv):
     skipped = False
 
     options, args = parse_args(argv)
+    if not options:
+        return ExitCodes.parse_error
 
-    if len(args) != 1:
+    if len(args) == 1:
+        srpm = args[0]
+        target = None
+    elif len(args) == 2:
+        srpm = args[0]
+        target = args[1]
+    else:
         gbp.log.err("Need to give exactly one package to import. Try --help.")
         return 1
     try:
@@ -215,7 +226,6 @@ def main(argv):
         gbp.log.err(err)
         return 1
     try:
-        srpm = args[0]
         if options.download:
             srpm = download_source(srpm)
 
@@ -240,7 +250,7 @@ def main(argv):
             dirs['src'] = os.path.abspath(srpm)
             spec = guess_spec(srpm, True, preferred_spec)
         else:
-            gbp.log.debug("Trying to import an srpm from '%s' with spec "\
+            gbp.log.debug("Trying to import an srpm from '%s' with spec "
                           "file '%s'" % (os.path.dirname(srpm), srpm))
             dirs['src'] = os.path.abspath(os.path.dirname(srpm))
             spec = SpecFile(srpm)
@@ -259,7 +269,8 @@ def main(argv):
         except GitRepositoryError:
             gbp.log.info("No git repository found, creating one.")
             is_empty = True
-            repo = RpmGitRepository.create(spec.name)
+            target = target or spec.name
+            repo = RpmGitRepository.create(target)
             os.chdir(repo.path)
 
         if repo.bare:
@@ -281,8 +292,8 @@ def main(argv):
             files = os.listdir(dirs['src'])
         else:
             # Need to copy files to the packaging directory given by caller
-            files = [os.path.basename(patch.path) \
-                    for patch in spec.patchseries(unapplied=True, ignored=True)]
+            files = [os.path.basename(patch.path)
+                     for patch in spec.patchseries(unapplied=True, ignored=True)]
             for filename in spec.sources().values():
                 files.append(os.path.basename(filename))
             files.append(os.path.join(spec.specdir, spec.specfile))
@@ -306,10 +317,18 @@ def main(argv):
         else:
             sources = None
 
-        src_tag_format = options.packaging_tag if options.native \
-                                               else options.upstream_tag
         tag_str_fields = dict(spec.version, vendor=options.vendor.lower())
-        src_tag = repo.version_to_tag(src_tag_format, tag_str_fields)
+        if options.native:
+            src_tag_format = options.packaging_tag
+            src_tag = repo.version_to_tag(src_tag_format, tag_str_fields)
+            upstream_tag = src_tag
+            upstream_str_fields = tag_str_fields
+        else:
+            src_tag_format = options.upstream_tag
+            src_tag = repo.version_to_tag(src_tag_format, tag_str_fields)
+            upstream_str_fields = filter_version(tag_str_fields, 'release', 'epoch')
+            upstream_tag = repo.version_to_tag(src_tag_format, upstream_str_fields)
+
         ver_str = compose_version_str(spec.version)
 
         if repo.find_version(options.packaging_tag, tag_str_fields):
@@ -339,7 +358,7 @@ def main(argv):
 
         # Import sources
         if sources:
-            src_commit = repo.find_version(src_tag_format, tag_str_fields)
+            src_commit = repo.find_version(src_tag_format, upstream_str_fields)
             if not src_commit:
                 gbp.log.info("Tag %s not found, importing sources" % src_tag)
 
@@ -351,17 +370,17 @@ def main(argv):
                                      branch)
                     else:
                         gbp.log.err(no_upstream_branch_msg % branch + "\n"
-                            "Also check the --create-missing-branches option.")
+                                    "Also check the --create-missing-branches option.")
                         raise GbpError
                 src_vendor = "Native" if options.native else "Upstream"
                 msg = "%s version %s" % (src_vendor, spec.upstreamversion)
                 src_commit = repo.commit_dir(sources.unpacked,
-                        "Imported %s" % msg,
-                        branch,
-                        author=author,
-                        committer=committer,
-                        create_missing_branch=options.create_missing_branches)
-                repo.create_tag(name=src_tag,
+                                             "Import %s" % msg,
+                                             branch,
+                                             author=author,
+                                             committer=committer,
+                                             create_missing_branch=options.create_missing_branches)
+                repo.create_tag(name=src_tag if options.native else upstream_tag,
                                 msg=msg,
                                 commit=src_commit,
                                 sign=options.sign_tags,
@@ -372,7 +391,7 @@ def main(argv):
                         archive_fmt = parse_archive_filename(orig_tarball)[1]
                         if archive_fmt == 'tar':
                             repo.pristine_tar.commit(orig_tarball,
-                                                    'refs/heads/%s' %
+                                                     'refs/heads/%s' %
                                                      options.upstream_branch)
                         else:
                             gbp.log.warn('Ignoring pristine-tar, %s archives '
@@ -399,11 +418,11 @@ def main(argv):
 
             if options.orphan_packaging or not sources:
                 commit = repo.commit_dir(dirs['packaging_base'],
-                        "Imported %s" % msg,
-                        branch,
-                        author=author,
-                        committer=committer,
-                        create_missing_branch=options.create_missing_branches)
+                                         "Import %s" % msg,
+                                         branch,
+                                         author=author,
+                                         committer=committer,
+                                         create_missing_branch=options.create_missing_branches)
             else:
                 # Copy packaging files to the unpacked sources dir
                 try:
@@ -417,12 +436,12 @@ def main(argv):
                     shutil.copy2(os.path.join(dirs['packaging'], fname),
                                  pkgsubdir)
                 commit = repo.commit_dir(sources.unpacked,
-                        "Imported %s" % msg,
-                        branch,
-                        other_parents=[src_commit],
-                        author=author,
-                        committer=committer,
-                        create_missing_branch=options.create_missing_branches)
+                                         "Import %s" % msg,
+                                         branch,
+                                         other_parents=[src_commit],
+                                         author=author,
+                                         committer=committer,
+                                         create_missing_branch=options.create_missing_branches)
                 # Import patches on top of the source tree
                 # (only for non-native packages with non-orphan packaging)
                 force_to_branch_head(repo, options.packaging_branch)
@@ -458,9 +477,10 @@ def main(argv):
         del_tmpdir()
 
     if not ret and not skipped:
-        gbp.log.info("Version '%s' imported under '%s'" % (ver_str, spec.name))
+        gbp.log.info("Version '%s' imported under '%s'" % (ver_str, repo.path))
     return ret
 
+
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
 
