@@ -29,6 +29,7 @@ from gbp.rpm import SrcRpmFile
 
 from tests.component import ComponentTestBase
 from tests.component.rpm import RPM_TEST_DATA_DIR as DATA_DIR
+from tests.testutils import capture_stderr
 
 # Disable "Method could be a function warning"
 # pylint: disable=R0201
@@ -36,7 +37,8 @@ from tests.component.rpm import RPM_TEST_DATA_DIR as DATA_DIR
 def mock_import(args):
     """Wrapper for import-srpm"""
     # Call import-orig-rpm with added arg0
-    return import_srpm.main(['arg0'] + args)
+    with capture_stderr():
+        return import_srpm.main(['arg0'] + args)
 
 
 class TestImportPacked(ComponentTestBase):
@@ -56,7 +58,9 @@ class TestImportPacked(ComponentTestBase):
         repo = GitRepository('gbp-test')
         files =  {'Makefile', 'README', 'bar.tar.gz', 'dummy.sh', 'foo.txt',
                   'gbp-test.spec', 'my.patch', 'my2.patch', 'my3.patch'}
-        self._check_repo_state(repo, 'master', ['master', 'upstream'], files)
+        self._check_repo_state(repo, 'master', ['master', 'upstream'],
+                               files=files,
+                               tags=['packaging/1.0-1', 'upstream/1.0'])
         # Two commits: upstream and packaging files
         eq_(len(repo.get_commits()), 2)
 
@@ -69,11 +73,21 @@ class TestImportPacked(ComponentTestBase):
         files = {'Makefile', 'README', 'bar.tar.gz', 'dummy.sh', 'foo.txt',
                  'gbp-test2.spec', 'gbp-test2-alt.spec', 'my.patch',
                  'my2.patch', 'my3.patch'}
-        self._check_repo_state(repo, 'master', ['master', 'upstream'], files)
-
+        self._check_repo_state(repo, 'master', ['master', 'upstream'],
+                               files=files,
+                               tags=['packaging/1%2.0-0', 'upstream/2.0'])
         # Two commits: upstream and packaging files
         eq_(len(repo.get_commits()), 2)
 
+    def test_target_dir(self):
+        """Test importing to target dir"""
+        srpm = os.path.join(DATA_DIR, 'gbp-test-1.0-1.src.rpm')
+        eq_(mock_import(['--no-pristine-tar', srpm, 'targetdir']), 0)
+        # Check repository state
+        assert os.path.exists('targetdir')
+        repo = GitRepository('targetdir')
+        self._check_repo_state(repo, 'master', ['master', 'upstream'])
+
     def test_basic_import_orphan(self):
         """
         Test importing of non-native src.rpm to separate packaging and
@@ -97,7 +111,9 @@ class TestImportPacked(ComponentTestBase):
         files = {'.gbp.conf', 'Makefile', 'README', 'dummy.sh',
                  'packaging/gbp-test-native.spec'}
         repo = GitRepository('gbp-test-native')
-        self._check_repo_state(repo, 'master', ['master'], files)
+        self._check_repo_state(repo, 'master', ['master'],
+                               files=files,
+                               tags=['packaging/1.0-1'])
         # Only one commit: the imported source tarball
         eq_(len(repo.get_commits()), 1)
 
@@ -274,7 +290,7 @@ class TestDownloadImport(ComponentTestBase):
         self._check_repo_state(repo, 'master', ['master', 'upstream'])
 
     def test_nonexistent_url(self):
-        """Test graceful failure when trying download from nonexistent url"""
+        """Test graceful failure when trying download from non-existent url"""
         srpm = 'http://honk.sigxcpu.org/does/not/exist'
         # Do not connect to remote, mock failure
         import_srpm.urlopen = Mock()
